<?php
/**
 * @version   $Id: styledeclaration.php 26437 2015-02-06 08:58:23Z arifin $
 * @author		RocketTheme http://www.rockettheme.com
 * @copyright 	Copyright (C) 2007 - 2019 RocketTheme, LLC
 * @license		http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 *
 * Gantry uses the Joomla Framework (http://www.joomla.org), a GNU/GPLv2 content management system
 *
 */
defined('JPATH_BASE') or die();

gantry_import('core.gantryfeature');

class GantryFeatureStyleDeclaration extends GantryFeature {
    var $_feature_name = 'styledeclaration';

    function isEnabled() {
		global $gantry;
        $menu_enabled = $this->get('enabled');

        if (1 == (int)$menu_enabled) return true;
        return false;
    }

    function init() {
        global $gantry, $ie_ver;
        $browser = $gantry->browser;

        if ($gantry->browser->name == 'ie' && $gantry->browser->shortversion == 8) $ie_ver = 'ie8';

        // Logo
    	$css = $this->buildLogo();

        // Less Variables
    	$lessVariables = array(
            'accent-color1'             => $gantry->get('accent-color1',                '#EA3E5C'),
            'accent-color2'             => $gantry->get('accent-color2',                '#00ACBA'),

            'top-textcolor'             => $gantry->get('top-textcolor',                '#000000'),
            'top-background'            => $gantry->get('top-background',               '#F6F6F6'),

            'header-textcolor'          => $gantry->get('header-textcolor',             '#000000'),
            'header-background'         => $gantry->get('header-background',            '#FFFFFF'),
            'header-type'               => $gantry->get('header-type',                  'normal'),
    
            'showcase-textcolor'        => $gantry->get('showcase-textcolor',           '#000000'),
            'showcase-background'       => $gantry->get('showcase-background',          '#EA3E5C'),
    
            'utility-textcolor'         => $gantry->get('utility-textcolor',            '#000000'),
            'utility-background'        => $gantry->get('utility-background',           '#FFFFFF'),
    
            'feature-textcolor'         => $gantry->get('feature-textcolor',            '#000000'),
            'feature-background'        => $gantry->get('feature-background',           '#F6F6F6'),
    
            'maintop-textcolor'         => $gantry->get('maintop-textcolor',            '#FFFFFF'),
            'maintop-background'        => $gantry->get('maintop-background',           '#000000'),
    
            'expandedtop-textcolor'     => $gantry->get('expandedtop-textcolor',        '#FFFFFF'),
            'expandedtop-background'    => $gantry->get('expandedtop-background',       '#000000'),

            'expandedbottom-textcolor'  => $gantry->get('expandedbottom-textcolor',     '#FFFFFF'),
            'expandedbottom-background' => $gantry->get('expandedbottom-background',    '#000000'),

            'mainbottom-textcolor'      => $gantry->get('mainbottom-textcolor',         '#FFFFFF'),
            'mainbottom-background'     => $gantry->get('mainbottom-background',        '#000000'),

            'mainbody-overlay'          => $gantry->get('mainbody-overlay',             'light'),

            'extension-textcolor'       => $gantry->get('extension-textcolor',          '#FFFFFF'),
            'extension-background'      => $gantry->get('extension-background',         '#EA3E5C'),

            'bottom-textcolor'          => $gantry->get('bottom-textcolor',             '#686868'),
            'bottom-background'         => $gantry->get('bottom-background',            '#000000'),

            'footer-textcolor'          => $gantry->get('footer-textcolor',             '#686868'),
            'footer-background'         => $gantry->get('footer-background',            '#000000'),

            'copyright-textcolor'       => $gantry->get('copyright-textcolor',          '#686868'),
            'copyright-background'      => $gantry->get('copyright-background',         '#000000')        
    	);

        // Section Background Images
        $positions  = array('showcase-custom-showcase-image', 'footer-custom-footer-image');
        $source     = "";

        foreach ($positions as $position) {
            $data = $gantry->get($position, false) ? json_decode(str_replace("'", '"', $gantry->get($position))) : false;
            if ($data) $source = $data->path;
            if (!preg_match('/^\//', $source)) $source = JURI::root(true).'/'.$source;
            $lessVariables[$position] = $data ? 'url(' . $source . ')' : 'none';
        }

        $gantry->addInlineStyle($css);

       	$gantry->addLess('global.less', 'master.css', 7, $lessVariables);

	    $this->_disableRokBoxForiPhone();

        if ($gantry->get('layout-mode')=="responsive") {
            $gantry->addLess('mediaqueries.less');
            $gantry->addLess('grid-flexbox-responsive.less');
            $gantry->addLess('menu-dropdown-direction.less');
        }
        if ($gantry->get('layout-mode')=="960fixed")   $gantry->addLess('960fixed.less');
        if ($gantry->get('layout-mode')=="1200fixed")  $gantry->addLess('1200fixed.less');

        // Scrolling Header
        if ($gantry->get('header-type')=="scroll") {
            $gantry->addScript('scrolling-header-normal.js');
        }

        // RTL
        if ($gantry->get('rtl-enabled')) $gantry->addLess('rtl.less', 'rtl.css', 8, $lessVariables);

        // Demo Styling
        if ($gantry->get('demo')) $gantry->addLess('demo.less', 'demo.css', 9, $lessVariables);

        // Third Party (k2)
        if ($gantry->get('k2')) $gantry->addLess('thirdparty-k2.less', 'thirdparty-k2.css', 10, $lessVariables);

        // Chart Script
        if ($gantry->get('chart-enabled')) $gantry->addScript('chart.js');

        // Animate
        if ($gantry->get('animate')){
            $gantry->addLess('animate.less');
            // WOW JS
            if ($ie_ver != 'ie8') {
                $gantry->addScript('wow.js');
                $gantry->addScript('wow-init.js');
            }
        }        
	}

    function buildLogo(){
		global $gantry;

        if ($gantry->get('logo-type')!="custom") return "";

        $source = $width = $height = "";

        $logo = str_replace("&quot;", '"', str_replace("'", '"', $gantry->get('logo-custom-image')));
        $data = json_decode($logo);

        if (!$data){
            if (strlen($logo)) $source = $logo;
            else return "";
        } else {
            $source = $data->path;
        }

        if (substr($gantry->baseUrl, 0, strlen($gantry->baseUrl)) == substr($source, 0, strlen($gantry->baseUrl))){
            $file = JPATH_ROOT . '/' . substr($source, strlen($gantry->baseUrl));
        } else {
            $file = JPATH_ROOT . '/' . $source;
        }

        if (isset($data->width) && isset($data->height)){
            $width = $data->width;
            $height = $data->height;
        } else {
            $size = @getimagesize($file);
            $width = $size[0];
            $height = $size[1];
        }

        if (!preg_match('/^\//', $source))
        {
            $source = JURI::root(true).'/'.$source;
        }

        $source = str_replace(' ', '%20', $source);

        $output = "";
        $output .= "#rt-logo {background: url(".$source.") 50% 0 no-repeat !important;}"."\n";
        $output .= "#rt-logo {width: ".$width."px;height: ".$height."px;}"."\n";

        $file = preg_replace('/\//i', DIRECTORY_SEPARATOR, $file);

        return (file_exists($file)) ?$output : '';
    }

	function _disableRokBoxForiPhone() {
		global $gantry;

		if ($gantry->browser->platform == 'iphone' || $gantry->browser->platform == 'android') {
			$gantry->addInlineScript("window.addEvent('domready', function() {\$\$('a[rel^=rokbox]').removeEvents('click');});");
		}
	}
}